@@ -31,7 +31,7 @@ import subprocess
 import sys
 import zipfile
 
-__version__ = "0.30.1"
+__version__ = "0.31.0"
 
 is_windows = os.name == "nt"
 
@@ -169,6 +169,7 @@ library."""
         "has_source": True,
         "cpus": os.cpu_count(),
         "pm_name": "",
+        "catch3": False,
     }
     package_manager = ask(
         "Package manager to use ([N]one/[c]onan/[v]cpkg)",
@@ -203,6 +204,7 @@ VCPKG_ROOT environment variable to be setup to vcpkg's root directory.""",
     d["exe"] = d["type_id"] == "e"
     d["lib"] = d["type_id"] == "s"
     d["header"] = d["type_id"] == "h"
+    d["catch3"] = d["cpp"] and d["std"] != "11" and d["pm"]
     return d
 
 
@@ -239,8 +241,6 @@ def should_install_file(name, d):
         return not d["exe"]
     if name == "windows-set-path.cmake":
         return not d["pm"]
-    if name == "install-script.cmake":
-        return d["exe"]
     if name == "header_impl.c":
         return d["c_header"] and d["pm"]
     if name == "clang-12.profile":
